==> dustrac_2.0.1.orig.tar.gz: DustRacing2D-2.0.1/src/game/translations/dustrac-game_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE" sourcelanguage="en">
<context>
    <name>MainMenu</name>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spielen</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Mitwirkende</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source> m</source>
        <translation type="vanished"> m</translation>
    </message>
    <message>
        <source>L:</source>
        <translatorcomment>Rundenrekord</translatorcomment>
        <translation>R: </translation>
    </message>
    <message>
        <source>R:</source>
        <translatorcomment>Streckenrekord</translatorcomment>
        <translation>S: </translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>On</source>
        <translation>An</translation>
    </message>
    <message>
        <source>---</source>
        <translation>---</translation>
    </message>
    <message>
        <source>1st</source>
        <translation>1.</translation>
    </message>
    <message>
        <source>2nd</source>
        <translation>2.</translation>
    </message>
    <message>
        <source>3rd</source>
        <translation>3.</translation>
    </message>
    <message>
        <source>4th</source>
        <translation>4.</translation>
    </message>
    <message>
        <source>5th</source>
        <translation>5.</translation>
    </message>
    <message>
        <source>6th</source>
        <translation>6.</translation>
    </message>
    <message>
        <source>7th</source>
        <translation>7.</translation>
    </message>
    <message>
        <source>8th</source>
        <translation>8.</translation>
    </message>
    <message>
        <source>9th</source>
        <translation>9.</translation>
    </message>
    <message>
        <source>LAP</source>
        <translation>Runde</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Aus</translation>
    </message>
    <message>
        <source>10th</source>
        <translation>10.</translation>
    </message>
    <message>
        <source>11th</source>
        <translation>11.</translation>
    </message>
    <message>
        <source>12th</source>
        <translation>12.</translation>
    </message>
    <message>
        <source>Easy</source>
        <translation>Einfach</translation>
    </message>
    <message>
        <source>Duel</source>
        <translation>Duell</translation>
    </message>
    <message>
        <source>LAP:</source>
        <translation>Runde: </translation>
    </message>
    <message>
        <source>LAPS</source>
        <translation>Runden</translation>
    </message>
    <message>
        <source>TOT:</source>
        <translation>Ges.: </translation>
    </message>
    <message>
        <source>RACE TRACKS BY</source>
        <translation type="vanished">Rennstrecken von</translation>
    </message>
    <message>
        <source> KM/H</source>
        <translation> km/h</translation>
    </message>
    <message>
        <source> LAP:</source>
        <translation> Runde: </translation>
    </message>
    <message>
        <source> POS:</source>
        <translation> Rang: </translation>
    </message>
    <message>
        <source>GFX &gt;</source>
        <translation>Grafik &gt;</translation>
    </message>
    <message>
        <source>GO!!!</source>
        <translation>Los!</translation>
    </message>
    <message>
        <source>Hard</source>
        <translation>Schwierig</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <source>SPECIAL THANKS</source>
        <translation>BESONDERES DANKESCHÖN AN</translation>
    </message>
    <message>
        <source>GAME GOAL

You are racing against eleven
computer players.

Your best position will be
the next start position.

Finish in TOP-6 to unlock
a new race track!

CONTROLS FOR PLAYER 1

Turn left  : Left
Turn right : Right
Accelerate : Up / RIGHT SHIFT
Brake      : Down / RIGHT CTRL

CONTROLS FOR PLAYER 2

Turn left  : A
Turn right : D
Accelerate : W / LEFT SHIFT
Brake      : S / LEFT CTRL

Quit       : ESC/Q
Pause      : P</source>
        <translation>SPIELZIEL

Sie fahren gegen elf
Computerspieler.

Ihre beste Position wird ihre
neue Startposition sein.

Beenden Sie das Rennen auf dem 6.
oder einem besserem Platz, um eine
neue Strecke freizuschalten.

STEUERUNG FÜR SPIELER 1

Links lenken: Links
Rechts lenken: Rechts
Gas geben: Hoch / Umschalt rechts
Bremsen: Runter / Steuerung rechts

STEUERUNG FÜR SPIELER 2

Links lenken: A
Rechts lenken: D
Gas geben: W / Umschalt links
Bremsen: S / Steuerung links

Beenden: Esc/Q
Pause: P</translation>
    </message>
    <message>
        <source>Reset unlocked tracks?</source>
        <translation>Freigeschaltete Strecken zurücksetzen?</translation>
    </message>
    <message>
        <source>New lap record!</source>
        <translation>Neuer Rundenrekord!</translation>
    </message>
    <message>
        <source>Player One Turn Left</source>
        <translation>Spieler 1: Links lenken</translation>
    </message>
    <message>
        <source>Restart to change the resolution.</source>
        <translation>Neustarten, um die Auflösung zu ändern.</translation>
    </message>
    <message>
        <source>A new track unlocked!</source>
        <translation>Eine neue Strecke freigeschaltet!</translation>
    </message>
    <message>
        <source>Split type &gt;</source>
        <translation>Art der Bildschirmteilung &gt;</translation>
    </message>
    <message>
        <source>Player Two Turn Left</source>
        <translation>Spieler 2: Links lenken</translation>
    </message>
    <message>
        <source>The winner has finished!</source>
        <translation>Der Sieger hat die Ziellinie überquert!</translation>
    </message>
    <message>
        <source>Reset best positions?</source>
        <translation>Bestpositionen zurücksetzen?</translation>
    </message>
    <message>
        <source>Race Record: </source>
        <translation>Streckenrekord: </translation>
    </message>
    <message>
        <source>Reset record times</source>
        <translation>Rekordzeiten zurücksetzen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Press a key..</source>
        <translation>Taste drücken ...</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mittel</translation>
    </message>
    <message>
        <source>Full screen resolution &gt;</source>
        <translation>Vollbildauflösung &gt;</translation>
    </message>
    <message>
        <source>Pit stop!</source>
        <translation>Boxenstopp!</translation>
    </message>
    <message>
        <source>Player Two Turn Right</source>
        <translation>Spieler 2: Rechts lenken</translation>
    </message>
    <message>
        <source>Sounds &gt;</source>
        <translation>Ton &gt;</translation>
    </message>
    <message>
        <source>Better luck next time..</source>
        <translation>Vielleicht klappt&apos;s beim nächsten Mal.</translation>
    </message>
    <message>
        <source>PROGRAMMING BY</source>
        <translation type="vanished">PROGRAMMIERUNG VON</translation>
    </message>
    <message>
        <source>       Laps: </source>
        <translation>        Runden: </translation>
    </message>
    <message>
        <source>Time Trial</source>
        <translation>Zeitrennen</translation>
    </message>
    <message>
        <source>Game mode &gt;</source>
        <translation>Spielmodus &gt;</translation>
    </message>
    <message>
        <source>Reset record times?</source>
        <translation>Rekordzeiten zurücksetzen?</translation>
    </message>
    <message>
        <source>Player One Brake</source>
        <translation>Spieler 1: Bremsen</translation>
    </message>
    <message>
        <source>Player One Accelerate</source>
        <translation>Spieler 1: Gas geben</translation>
    </message>
    <message>
        <source>Reset &gt;</source>
        <translation>Zurücksetzen &gt;</translation>
    </message>
    <message>
        <source>The Time Trial has ended!</source>
        <translation>Das Zeitrennen ist vorbei!</translation>
    </message>
    <message>
        <source>You must stay on track!</source>
        <translation>Sie müssen auf der Strecke bleiben!</translation>
    </message>
    <message>
        <source>CONTRIBUTORS</source>
        <translation type="vanished">MITWIRKENDE</translation>
    </message>
    <message>
        <source>Reset best positions</source>
        <translation>Bestpositionen zurücksetzen</translation>
    </message>
    <message>
        <source>Lap Count &gt;</source>
        <translation type="vanished">Rundenzahl &gt;</translation>
    </message>
    <message>
        <source>     Length: </source>
        <translation>     Länge: </translation>
    </message>
    <message>
        <source>Restart to change VSync setting.</source>
        <translation>Neustarten, um VSync-Einstellung zu ändern.</translation>
    </message>
    <message>
        <source>Reset unlocked tracks</source>
        <translation>Freigeschaltete Strecken zurücksetzen</translation>
    </message>
    <message>
        <source>One player race</source>
        <translation>Einspielerrennen</translation>
    </message>
    <message>
        <source>Controls &gt;</source>
        <translation>Steuerung &gt;</translation>
    </message>
    <message>
        <source>VSync &gt;</source>
        <translation>Vertikale Synchronisation &gt;</translation>
    </message>
    <message>
        <source>GRAPHICS BY</source>
        <translation type="vanished">GRAFIK VON</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertikal</translation>
    </message>
    <message>
        <source>Player One Turn Right</source>
        <translation>Spieler 1: Rechts lenken</translation>
    </message>
    <message>
        <source>Two player race</source>
        <translation>Zweispielerrennen</translation>
    </message>
    <message>
        <source>Watch your tires!</source>
        <translation>Achten Sie auf Ihre Reifen!</translation>
    </message>
    <message>
        <source>Difficulty &gt;</source>
        <translation type="vanished">Schwierigkeitsgrad &gt;</translation>
    </message>
    <message>
        <source>Player Two Brake</source>
        <translation>Spieler 2: Bremsen</translation>
    </message>
    <message>
        <source>A new best pos!</source>
        <translation>Eine neue Bestposition!</translation>
    </message>
    <message>
        <source>Player Two Accelerate</source>
        <translation>Spieler 2: Gas geben</translation>
    </message>
    <message>
        <source> Lap Record: </source>
        <translation> Rundenrekord: </translation>
    </message>
    <message>
        <source>New race record!</source>
        <translation>Neuer Streckenrekord!</translation>
    </message>
    <message>
        <source>Windowed resolution &gt;</source>
        <translation>Fensterauflösung &gt;</translation>
    </message>
    <message>
        <source>PROGRAMMING</source>
        <translation>Programmierung</translation>
    </message>
    <message>
        <source>GRAPHICS</source>
        <translation>Grafik</translation>
    </message>
    <message>
        <source>LEVEL DESIGN</source>
        <translation>Level-Design</translation>
    </message>
    <message>
        <source>TRANSLATIONS</source>
        <translation>Übersetzungen</translation>
    </message>
    <message>
        <source>PATCHES</source>
        <translation>Patches</translation>
    </message>
    <message>
        <source>Choose lap count</source>
        <translation>Wählen Sie die Rundenzahl</translation>
    </message>
</context>
</TS>

==> dustrac_2.0.5.orig.tar.gz: DustRacing2D-2.0.5/src/game/translations/dustrac-game_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE" sourcelanguage="en">
<context>
    <name>MainMenu</name>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spielen</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Mitwirkende</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source> m</source>
        <translation type="vanished"> m</translation>
    </message>
    <message>
        <source>L:</source>
        <extracomment>Last lap time</extracomment>
        <translatorcomment>Letzte Rundenzeit</translatorcomment>
        <translation>L: </translation>
    </message>
    <message>
        <source>R:</source>
        <extracomment>Lap record time</extracomment>
        <translatorcomment>Rundenrekord</translatorcomment>
        <translation>R: </translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>On</source>
        <translation>An</translation>
    </message>
    <message>
        <source>---</source>
        <translation>---</translation>
    </message>
    <message>
        <source>1st</source>
        <translation>1.</translation>
    </message>
    <message>
        <source>2nd</source>
        <translation>2.</translation>
    </message>
    <message>
        <source>3rd</source>
        <translation>3.</translation>
    </message>
    <message>
        <source>4th</source>
        <translation>4.</translation>
    </message>
    <message>
        <source>5th</source>
        <translation>5.</translation>
    </message>
    <message>
        <source>6th</source>
        <translation>6.</translation>
    </message>
    <message>
        <source>7th</source>
        <translation>7.</translation>
    </message>
    <message>
        <source>8th</source>
        <translation>8.</translation>
    </message>
    <message>
        <source>9th</source>
        <translation>9.</translation>
    </message>
    <message>
        <source>LAP</source>
        <translation>Runde</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Aus</translation>
    </message>
    <message>
        <source>10th</source>
        <translation>10.</translation>
    </message>
    <message>
        <source>11th</source>
        <translation>11.</translation>
    </message>
    <message>
        <source>12th</source>
        <translation>12.</translation>
    </message>
    <message>
        <source>Easy</source>
        <translation>Einfach</translation>
    </message>
    <message>
        <source>Duel</source>
        <translation>Duell</translation>
    </message>
    <message>
        <source>LAP:</source>
        <translation>Runde: </translation>
    </message>
    <message>
        <source>LAPS</source>
        <translation>Runden</translation>
    </message>
    <message>
        <source>TOT:</source>
        <extracomment>Total race time</extracomment>
        <translation>Ges.: </translation>
    </message>
    <message>
        <source>RACE TRACKS BY</source>
        <translation type="vanished">Rennstrecken von</translation>
    </message>
    <message>
        <source> KM/H</source>
        <translation> km/h</translation>
    </message>
    <message>
        <source> LAP:</source>
        <translation> Runde: </translation>
    </message>
    <message>
        <source> POS:</source>
        <extracomment>Position/rank</extracomment>
        <translation> Rang: </translation>
    </message>
    <message>
        <source>GFX &gt;</source>
        <translation>Grafik &gt;</translation>
    </message>
    <message>
        <source>GO!!!</source>
        <translation>Los!</translation>
    </message>
    <message>
        <source>Hard</source>
        <translation>Schwierig</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <source>SPECIAL THANKS</source>
        <translation>BESONDERES DANKESCHÖN AN</translation>
    </message>
    <message>
        <source>GAME GOAL

You are racing against eleven
computer players.

Your best position will be
the next start position.

Finish in TOP-6 to unlock
a new race track!

CONTROLS FOR PLAYER 1

Turn left  : Left
Turn right : Right
Accelerate : Up / RIGHT SHIFT
Brake      : Down / RIGHT CTRL

CONTROLS FOR PLAYER 2

Turn left  : A
Turn right : D
Accelerate : W / LEFT SHIFT
Brake      : S / LEFT CTRL

Quit       : ESC/Q
Pause      : P</source>
        <translation>SPIELZIEL

Sie fahren gegen elf
Computerspieler.

Ihre beste Position wird ihre
neue Startposition sein.

Beenden Sie das Rennen auf dem 6.
oder einem besserem Platz, um eine
neue Strecke freizuschalten.

STEUERUNG FÜR SPIELER 1

Links lenken: Links
Rechts lenken: Rechts
Gas geben: Hoch / Umschalt rechts
Bremsen: Runter / Steuerung rechts

STEUERUNG FÜR SPIELER 2

Links lenken: A
Rechts lenken: D
Gas geben: W / Umschalt links
Bremsen: S / Steuerung links

Beenden: Esc/Q
Pause: P</translation>
    </message>
    <message>
        <source>Reset unlocked tracks?</source>
        <translation>Freigeschaltete Strecken zurücksetzen?</translation>
    </message>
    <message>
        <source>New lap record!</source>
        <translation>Neuer Rundenrekord!</translation>
    </message>
    <message>
        <source>Player One Turn Left</source>
        <translation>Spieler 1: Links lenken</translation>
    </message>
    <message>
        <source>Restart to change the resolution.</source>
        <translation>Neustarten, um die Auflösung zu ändern.</translation>
    </message>
    <message>
        <source>A new track unlocked!</source>
        <translation>Eine neue Strecke freigeschaltet!</translation>
    </message>
    <message>
        <source>Split type &gt;</source>
        <translation>Art der Bildschirmteilung &gt;</translation>
    </message>
    <message>
        <source>Player Two Turn Left</source>
        <translation>Spieler 2: Links lenken</translation>
    </message>
    <message>
        <source>The winner has finished!</source>
        <translation>Der Sieger hat die Ziellinie überquert!</translation>
    </message>
    <message>
        <source>Reset best positions?</source>
        <translation>Bestpositionen zurücksetzen?</translation>
    </message>
    <message>
        <source>Race Record: </source>
        <translation>  Rennrekord: </translation>
    </message>
    <message>
        <source>Reset record times</source>
        <translation>Rekordzeiten zurücksetzen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Press a key..</source>
        <translation>Taste drücken ...</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mittel</translation>
    </message>
    <message>
        <source>Full screen resolution &gt;</source>
        <translation>Vollbildauflösung &gt;</translation>
    </message>
    <message>
        <source>Pit stop!</source>
        <translation>Boxenstopp!</translation>
    </message>
    <message>
        <source>Player Two Turn Right</source>
        <translation>Spieler 2: Rechts lenken</translation>
    </message>
    <message>
        <source>Sounds &gt;</source>
        <translation>Ton &gt;</translation>
    </message>
    <message>
        <source>Better luck next time..</source>
        <translation>Vielleicht klappt&apos;s beim nächsten Mal.</translation>
    </message>
    <message>
        <source>PROGRAMMING BY</source>
        <translation type="vanished">PROGRAMMIERUNG VON</translation>
    </message>
    <message>
        <source>       Laps: </source>
        <translation>      Runden: </translation>
    </message>
    <message>
        <source>Time Trial</source>
        <translation>Zeitrennen</translation>
    </message>
    <message>
        <source>Game mode &gt;</source>
        <translation>Spielmodus &gt;</translation>
    </message>
    <message>
        <source>Reset record times?</source>
        <translation>Rekordzeiten zurücksetzen?</translation>
    </message>
    <message>
        <source>Player One Brake</source>
        <translation>Spieler 1: Bremsen</translation>
    </message>
    <message>
        <source>Player One Accelerate</source>
        <translation>Spieler 1: Gas geben</translation>
    </message>
    <message>
        <source>Reset &gt;</source>
        <translation>Zurücksetzen &gt;</translation>
    </message>
    <message>
        <source>The Time Trial has ended!</source>
        <translation>Das Zeitrennen ist vorbei!</translation>
    </message>
    <message>
        <source>You must stay on track!</source>
        <translation>Sie müssen auf der Strecke bleiben!</translation>
    </message>
    <message>
        <source>CONTRIBUTORS</source>
        <translation type="vanished">MITWIRKENDE</translation>
    </message>
    <message>
        <source>Reset best positions</source>
        <translation>Bestpositionen zurücksetzen</translation>
    </message>
    <message>
        <source>Lap Count &gt;</source>
        <translation type="vanished">Rundenzahl &gt;</translation>
    </message>
    <message>
        <source>     Length: </source>
        <translation>       Länge: </translation>
    </message>
    <message>
        <source>Restart to change VSync setting.</source>
        <translation>Neustarten, um VSync-Einstellung zu ändern.</translation>
    </message>
    <message>
        <source>Reset unlocked tracks</source>
        <translation>Freigeschaltete Strecken zurücksetzen</translation>
    </message>
    <message>
        <source>One player race</source>
        <translation>Einspielerrennen</translation>
    </message>
    <message>
        <source>Controls &gt;</source>
        <translation>Steuerung &gt;</translation>
    </message>
    <message>
        <source>VSync &gt;</source>
        <translation>Vertikale Synchronisation &gt;</translation>
    </message>
    <message>
        <source>GRAPHICS BY</source>
        <translation type="vanished">GRAFIK VON</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertikal</translation>
    </message>
    <message>
        <source>Player One Turn Right</source>
        <translation>Spieler 1: Rechts lenken</translation>
    </message>
    <message>
        <source>Two player race</source>
        <translation>Zweispielerrennen</translation>
    </message>
    <message>
        <source>Watch your tires!</source>
        <translation>Schonen Sie Ihre Reifen!</translation>
    </message>
    <message>
        <source>Difficulty &gt;</source>
        <translation type="vanished">Schwierigkeitsgrad &gt;</translation>
    </message>
    <message>
        <source>Player Two Brake</source>
        <translation>Spieler 2: Bremsen</translation>
    </message>
    <message>
        <source>A new best pos!</source>
        <translation>Eine neue Bestposition!</translation>
    </message>
    <message>
        <source>Player Two Accelerate</source>
        <translation>Spieler 2: Gas geben</translation>
    </message>
    <message>
        <source> Lap Record: </source>
        <translation>Rundenrekord: </translation>
    </message>
    <message>
        <source>New race record!</source>
        <translation>Neuer Rennrekord!</translation>
    </message>
    <message>
        <source>Windowed resolution &gt;</source>
        <translation>Fensterauflösung &gt;</translation>
    </message>
    <message>
        <source>PROGRAMMING</source>
        <translation>PROGRAMMIERUNG</translation>
    </message>
    <message>
        <source>GRAPHICS</source>
        <translation>GRAFIK</translation>
    </message>
    <message>
        <source>LEVEL DESIGN</source>
        <translation>LEVEL-DESIGN</translation>
    </message>
    <message>
        <source>TRANSLATIONS</source>
        <translation>ÜBERSETZUNGEN</translation>
    </message>
    <message>
        <source>PATCHES</source>
        <translation>PATCHES</translation>
    </message>
    <message>
        <source>Choose lap count</source>
        <translation>Wählen Sie die Rundenzahl</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>60 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS &gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
